<div align="center">

# TorchNyan

![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/speedcell4/torchnyan/unit-tests.yml?cacheSeconds=0)
![PyPI - Version](https://img.shields.io/pypi/v/torchnyan?label=pypi%20version&cacheSeconds=0)
![PyPI - Downloads](https://img.shields.io/pypi/dm/torchnyan?cacheSeconds=0)

</div>

## Installation

`python -m pip torchnyan`